==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/fil/admin/custom_fields/general.php <==
<?php

return array(
    'custom_fields'		        => 'I-kuston ang mga Fields',
    'field'		                => 'Ang Field',
    'about_fieldsets_title'		=> 'Ang Tungkol sa Fieldsets',
    'about_fieldsets_text'		=> 'Ang Fieldsets ay nagbibigay permiso sa iyo na magsagawa ng grupo ng kustom na mga fields na madalas na ginagamit muli para sa partikular na tipo ng modelo ng asset.',
    'custom_format'             => 'I-kustom ang pormat ng regex...',
    'encrypt_field'      	        => 'I-encrypt ang balyu sa field na ito sa database',
    'encrypt_field_help'      => 'BABALA: Ang pag-encrypt ng field ay maaaring maging hindi na ito maisaliksik.',
    'encrypted'      	        => 'Na-encrypt na',
    'fieldset'      	        => 'Ang Fieldset',
    'qty_fields'      	      => 'Ang Qty ng Fields',
    'fieldsets'      	        => 'Ang mga Fieldset',
    'fieldset_name'           => 'Ang Pangalang ng Fieldset',
    'field_name'              => 'Ang Pangalang ng Field',
    'field_values'            => 'Ang mga Balyu ng Field',
    'field_values_help'       => 'Magdagdag ng mga opsyon na madaling mapili, isa bawat linya. Ang mga blangkong linya maliban sa unang linya ay huwag intindihin.',
    'field_element'           => 'Ang Form ng Elemento',
    'field_element_short'     => 'Ang Elemento',
    'field_format'            => 'Ang Pormat',
    'field_custom_format'     => 'I-kustom ang Pormat ng Regex',
    'field_custom_format_help'     => 'Ang field na ito ay nagbibigay permiso sa iyo na ekpresyon ng regex para sa pag-validate. ito ay dapat na magsimula sa "regex:" - halimbawa, upang ma-validate balyu ng nakustomang field na naglalaman ng balidong IMEI (15 numeric digits), ikaw ay gagamit ng <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Kinakailangan',
    'req'   		              => 'Kinakailangan.',
    'used_by_models'   		    => 'Ginagamit ng mga Modelo',
    'order'   		            => 'Ang Kaayusan',
    'create_fieldset'         => 'Ang Bagong Fieldset',
    'create_field'            => 'Ang Bagong Custom Field',
    'value_encrypted'      	        => 'Ang balyu ng field na ito ay naka-encrypt sa database. Ang admin na mga gumagamit lamang ang maaaring maka-tanaw sa na-decrypt na balyu',
    'show_in_email'     => 'Include the value of this field in checkout emails sent to the user? Encrypted fields cannot be included in emails.',
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/fil/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'I-kuston ang mga Fields',
    'manage'                    => 'Manage',
    'field'		                => 'Ang Field',
    'about_fieldsets_title'		=> 'Ang Tungkol sa Fieldsets',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'I-encrypt ang balyu sa field na ito sa database',
    'encrypt_field_help'      => 'BABALA: Ang pag-encrypt ng field ay maaaring maging hindi na ito maisaliksik.',
    'encrypted'      	        => 'Na-encrypt na',
    'fieldset'      	        => 'Ang Fieldset',
    'qty_fields'      	      => 'Ang Qty ng Fields',
    'fieldsets'      	        => 'Ang mga Fieldset',
    'fieldset_name'           => 'Ang Pangalang ng Fieldset',
    'field_name'              => 'Ang Pangalang ng Field',
    'field_values'            => 'Ang mga Balyu ng Field',
    'field_values_help'       => 'Magdagdag ng mga opsyon na madaling mapili, isa bawat linya. Ang mga blangkong linya maliban sa unang linya ay huwag intindihin.',
    'field_element'           => 'Ang Form ng Elemento',
    'field_element_short'     => 'Ang Elemento',
    'field_format'            => 'Ang Pormat',
    'field_custom_format'     => 'I-kustom ang Pormat ng Regex',
    'field_custom_format_help'     => 'Ang field na ito ay nagbibigay permiso sa iyo na ekpresyon ng regex para sa pag-validate. ito ay dapat na magsimula sa "regex:" - halimbawa, upang ma-validate balyu ng nakustomang field na naglalaman ng balidong IMEI (15 numeric digits), ikaw ay gagamit ng <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Kinakailangan',
    'req'   		              => 'Kinakailangan.',
    'used_by_models'   		    => 'Ginagamit ng mga Modelo',
    'order'   		            => 'Ang Kaayusan',
    'create_fieldset'         => 'Ang Bagong Fieldset',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'Ang Bagong Custom Field',
    'create_field_title' => 'Create a new custom field',
    'value_encrypted'      	        => 'Ang balyu ng field na ito ay naka-encrypt sa database. Ang admin na mga gumagamit lamang ang maaaring maka-tanaw sa na-decrypt na balyu',
    'show_in_email'     => 'Include the value of this field in checkout emails sent to the user? Encrypted fields cannot be included in emails.',
    'help_text' => 'Help Text',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Reorder',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code> :db_column </code> but should be :expected </code>.',
    'is_unique' => 'This value must be unique across all assets',
    'unique' => 'Unique',
];
